@@ -3,8 +3,8 @@ import requests
 
 class ManageFiles():
     def __init__(self, config):
-        self.fms_host = config['FMS_HOST'] or '10.1.0.5'
-        self.fms_port = config['FMS_PORT'] or '8007'
+        self.fms_host = config['FMS_HOST']
+        self.fms_port = config['FMS_PORT'] 
         self.fms_url = f"{self.fms_host}:{self.fms_port}"
         self.base_location = os.getcwd()
         
@@ -18,7 +18,7 @@ class ManageFiles():
                 for chunk in response.iter_content(chunk_size=1024): 
                     file.write(chunk)
             response.close()
-        return f"File Donwloaded Successfully {file_key}.{ext}"
+        return f"File Donwloaded Successfully {file_key}.{ext}", file_key, ext
 
     def upload_file(self, file_key, ext, location, group, created_by):
         url = f"http://{self.fms_url}/{file_key}"
